@@ -110,7 +110,7 @@ _build_reencode_cmd(const char *extension, const char *filename,
 		    filename, extension);
 		return (NULL);
 	}
-	encoder = cfg_encoder_list_get(cfg_get_encoders(),
+	encoder = cfg_encoder_list_find(cfg_get_encoders(),
 	    cfg_stream_get_encoder(cfg_stream));
 	if (!encoder) {
 		log_error("cannot encode: %s: unknown encoder",
@@ -285,6 +285,10 @@ openResource(stream_t stream, const char *filename, int *popenFlag,
 
 		pCommandString = _build_reencode_cmd(extension, filename,
 		    cfg_stream, md);
+		if (NULL == pCommandString) {
+			mdata_destroy(&md);
+			return (NULL);
+		}
 		if (md_p != NULL)
 			*md_p = md;
 		else
