@@ -1,8 +1,7 @@
-/*	$Id$	*/
 /*
  *  ezstream - source client for Icecast with external en-/decoder support
  *  Copyright (C) 2003, 2004, 2005, 2006  Ed Zaleski <oddsock@oddsock.org>
- *  Copyright (C) 2007                    Moritz Grimm <mgrimm@mrsserver.net>
+ *  Copyright (C) 2007, 2017              Moritz Grimm <mgrimm@mrsserver.net>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License version 2 as
@@ -12,26 +11,28 @@
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 #ifndef __UTIL_H__
 #define __UTIL_H__
 
-#include <shout/shout.h>
+#ifndef UTIL_DEFAULT_PROGNAME
+# define UTIL_DEFAULT_PROGNAME  "ezstream"
+#endif /* !UTIL_DEFAULT_PROGNAME */
 
-#define ICONV_REPLACE		0
-#define ICONV_TRANSLIT		1
-#define ICONV_IGNORE		2
+struct util_dict {
+	const char	*from;
+	const char	*to;
+};
 
-int		strrcmp(const char *, const char *);
-int		strrcasecmp(const char *, const char *);
-shout_t *	stream_setup(const char *, unsigned short, const char *);
-char *		CHARtoUTF8(const char *, int);
-char *		UTF8toCHAR(const char *, int);
-int		ez_gettimeofday(void *);
+const char *
+	util_get_progname(const char *);
+int	util_write_pid_file(const char *);
+int	util_strrcmp(const char *, const char *);
+int	util_strrcasecmp(const char *, const char *);
+char *	util_char2utf8(const char *);
+char *	util_utf82char(const char *);
+char *	util_expand_words(const char *, struct util_dict[]);
+char *	util_shellquote(const char *, size_t);
 
 #endif /* __UTIL_H__ */
